//
//  GBFileItem.h
//  gBrowser
//
//  Created by Andreas Schwarz on Thu Apr 18 2002.
//  Copyright (c) 2001 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <AASFilesystemTools/AASFilesystemTools.h>
#import "GBMarkableItemProtocol.h"
#import "GBTypes.h"





@interface GBFileItem : AASBasicInfoFileItem <GBMarkableItemProtocol> {
    /// More file info ///	
    NSString *fileType;
    
    NSImage *fileIcon;
    NSImage *genericIcon;
    char hasCustomIcon;
    
    NSString *modificationDateString;
    
    NSDate *creationDate;
    NSString *creationDateString;
    	
    NSString *fileSizeString;
    NSString *dataForkSizeString;
    BOOL fileSizeFound;
    unsigned long long fileSize;
    unsigned long long dataForkSize;
    
    NSString *resolvedFileType;
	
    char isImage;
    char isText;
    char isMovie;
    char isMusic;
    char isInTrash;
    
	NSInteger imageOrientation;
        
    BOOL foundImageData;
	char imageMetadataEditable;
    
	NSDictionary *imageProperties;
	NSMutableDictionary *marks;
	NSMutableDictionary *imageInformation;
}


#pragma mark -
#pragma mark File Information

@property(readonly) NSString * fileSizeString;
@property(readonly) NSString * dataForkSizeString;

@property(readonly) unsigned long long fileSize;
@property(readonly) unsigned long long dataForkSize;

@property(readonly) NSString * modificationDateString;
@property(readonly) NSString * creationDateString;
@property(readonly) NSDate * creationDate;

@property(readonly) NSString * displayNamePath;

@property(readonly) BOOL isImage;
@property(readonly) BOOL isMovie;
@property(readonly) BOOL isText;
@property(readonly) BOOL isMusic;

@property(readonly) BOOL isMedia;

@property(readonly) BOOL isInTrash;

@property(readonly) GBFileItem *preferredApplication;
@property(readonly) GBFileItem *editorApplication;




#pragma mark -
#pragma mark Image Information

@property(readonly) NSDictionary * imageInformation;

/* Keys for imageInformation dictionary:
 Orientation
 EXIFDate
 EXIFDateString
 TrueDimensions
 Dimensions
 DimensionsString
 Megapixels
 MegapixelString
 ImageDepthString
 ICCProfileString
 ISO
 ISOString
 ExposureTime
 ExposureTimeString
 FNumber
 FNumberString
 ResolutionString
 GeneralOrientation
 GeneralOrientationString
 FocalLength
 FocalLengthString
 CameraModelString
 */

@property (readonly) BOOL hasEditableImageMetadata;
- (BOOL)setImageOrientation:(NSInteger)newOrientation;



#pragma mark -
#pragma mark Icons and Thumbnails

@property(readonly) NSImage * fileIcon;
@property(readonly) NSImage * genericIcon;

@property(readonly) BOOL hasCustomIcon;




#pragma mark -


- (BOOL)countOfFiles:(NSUInteger *)files folders:(NSUInteger *)folders total:(NSUInteger *)total fileFilter:(AASFileFilter *)fileFilter directoryFilter:(AASFileFilter *)directoryFilter;




#pragma mark -
#pragma mark Actions


- (BOOL)setAsDesktopPicture:(NSInteger)screenNumber;




#pragma mark -
#pragma mark Sorting Functions

- (NSComparisonResult)sortFilesByName:(id)otherItem;
- (NSComparisonResult)sortFilesByPath:(id)otherItem;

CFComparisonResult GBFileSortByContext(const void *obj1, const void *obj2, void *context);
CFComparisonResult GBFileSort(id obj1, id obj2, NSUInteger type, NSUInteger reverseSort, NSUInteger folderSort);


#pragma mark -
#pragma mark Filter Class Methods

+ (NSNumber *)filterImages:(GBFileItem *)file;
+ (NSNumber *)filterNoFolders:(GBFileItem *)file;
+ (NSNumber *)filterSupportedTypes:(GBFileItem *)file;


@end








